@@ -40,6 +40,11 @@ class MultiVariateMultiStep(ABC):
     def set_model_id(self, name: str):
         pass
 
+    @property
+    @abstractmethod
+    def get_model_id(self) -> str:
+        pass
+
     @property
     @abstractmethod
     def get_X_input(self) -> array:
@@ -60,6 +65,11 @@ class MultiVariateMultiStep(ABC):
     def get_y_input_shape(self) -> tuple:
         pass
 
+    @property
+    @abstractmethod
+    def get_optimizer(self) -> str:
+        pass
+
     @property
     @abstractmethod
     def get_loss(self) -> str:
@@ -93,7 +103,7 @@ class MultiVariateMultiStep(ABC):
         pass
 
     @abstractmethod
-    def save_model(self):
+    def save_model(self, absolute_path: str):
         pass
 
     @abstractmethod
