@@ -32,6 +32,11 @@ class UniVariateMultiStep(ABC):
     def set_model_id(self, name: str):
         pass
 
+    @property
+    @abstractmethod
+    def get_model_id(self) -> str:
+        pass
+
     @property
     @abstractmethod
     def get_X_input(self) -> array:
@@ -52,6 +57,11 @@ class UniVariateMultiStep(ABC):
     def get_y_input_shape(self) -> tuple:
         pass
 
+    @property
+    @abstractmethod
+    def get_optimizer(self) -> str:
+        pass
+
     @property
     @abstractmethod
     def get_loss(self) -> str:
@@ -85,7 +95,7 @@ class UniVariateMultiStep(ABC):
         pass
 
     @abstractmethod
-    def save_model(self):
+    def save_model(self, absolute_path: str):
         pass
 
     @abstractmethod
