@@ -44,6 +44,8 @@ class HybridMultStepUniVar(UniVariateMultiStep):
             Private method to prepare data for predictor ingestion.
         set_model_id(self, name: str):
             Setter method to change model id name.
+        get_model_id(self) -> array:
+            Getter method to retrieve model id used.
         get_X_input(self) -> array:
             Getter method to retrieve transformed X input - training.
         get_X_input_shape(self) -> tuple:
@@ -52,6 +54,8 @@ class HybridMultStepUniVar(UniVariateMultiStep):
             Getter method to retrieve transformed y input - target.
         get_y_input_shape(self) -> array:
             Getter method to retrieve transformed y input shape.
+        get_optimizer(self) -> str:
+            Getter method to retrieve model optimizer used.
         get_loss(self) -> str:
             Getter method to retrieve used model loss.
         get_metrics(self) -> str:
@@ -96,12 +100,14 @@ class HybridMultStepUniVar(UniVariateMultiStep):
             Evaluate and plot model performance.
         predict(self, data: array):
             Takes in input data and outputs model forecasts.
-        save_model(self):
-            Saves current ceras model to current directory.
+        save_model(self, absolute_path: str = CURRENT_PATH):
+            Saves current Keras model to current directory.
         load_model(self, location: str):
             Load model from location specified.
     '''
 
+    CURRENT_PATH = os.getcwd()
+
     def __init__(
             self,
             sub_seq: int,
@@ -122,6 +128,7 @@ class HybridMultStepUniVar(UniVariateMultiStep):
         self.sub_seq = sub_seq
         self.steps_past = steps_past
         self.steps_future = steps_future
+        self.optimizer = ''
         self.loss = ''
         self.metrics = ''
 
@@ -225,6 +232,12 @@ class HybridMultStepUniVar(UniVariateMultiStep):
         '''
         self.model_id = name
 
+    @property
+    def get_model_id(self) -> str:
+        '''Get model id.
+        '''
+        return self.model_id
+
     @property
     def get_X_input(self) -> array:
         '''Get transformed feature data.
@@ -249,6 +262,12 @@ class HybridMultStepUniVar(UniVariateMultiStep):
         '''
         return self.input_y.shape
 
+    @property
+    def get_optimizer(self) -> str:
+        '''Get model optimizer.
+        '''
+        return self.optimizer
+
     @property
     def get_loss(self) -> str:
         '''Get loss function.
@@ -290,6 +309,7 @@ class HybridMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('CNN-RNN')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -333,6 +353,7 @@ class HybridMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('CNN-LSTM')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -376,6 +397,7 @@ class HybridMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('CNN-GRU')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -419,6 +441,7 @@ class HybridMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('CNN-BI-RNN')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -462,6 +485,7 @@ class HybridMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('CNN-BI-LSTM')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -505,6 +529,7 @@ class HybridMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('CNN-BI-GRU')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -595,14 +620,16 @@ class HybridMultStepUniVar(UniVariateMultiStep):
 
         return pd.DataFrame(y_pred, columns=[f'{self.model_id}'])
 
-    def save_model(self):
+    def save_model(self, absolute_path: str = CURRENT_PATH):
         '''Save the current model to the current directory.
+             Parameters:
+                absolute_path (str): Path to save model to.
         '''
-        self.model.save(os.path.abspath(os.getcwd()))
+        self.model.save(absolute_path)
 
     def load_model(self, location: str):
         '''Load a keras model from the path specified.
             Parameters:
-                location (str): Path of keras model location
+                location (str): Path of keras model location.
         '''
         self.model = keras.models.load_model(location)
