@@ -45,6 +45,8 @@ class BasicMultStepUniVar(UniVariateMultiStep):
             Private method to prepare data for predictor ingestion.
         set_model_id(self, name: str):
             Setter method to change model id name.
+        get_model_id(self) -> array:
+            Getter method to retrieve model id used.
         get_X_input(self) -> array:
             Getter method to retrieve transformed X input - training.
         get_X_input_shape(self) -> tuple:
@@ -53,6 +55,8 @@ class BasicMultStepUniVar(UniVariateMultiStep):
             Getter method to retrieve transformed y input - target.
         get_y_input_shape(self) -> array:
             Getter method to retrieve transformed y input shape.
+        get_optimizer(self) -> str:
+            Getter method to retrieve model optimizer used.
         get_loss(self) -> str:
             Getter method to retrieve used model loss.
         get_metrics(self) -> str:
@@ -124,12 +128,14 @@ class BasicMultStepUniVar(UniVariateMultiStep):
             Evaluate and plot model performance.
         predict(self, data: array):
             Takes in input data and outputs model forecasts.
-        save_model(self):
+        save_model(self, absolute_path: str = CURRENT_PATH):
             Saves current Keras model to current directory.
         load_model(self, location: str):
             Load model from location specified.
     '''
 
+    CURRENT_PATH = os.getcwd()
+
     def __init__(
             self,
             steps_past: int,
@@ -144,6 +150,8 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 scale (str): How to scale the data before making predictions.
         '''
         self.scaler = self._scaling(scale)
+        self.model_id = ''
+        self.optimizer = ''
         self.loss = ''
         self.metrics = ''
 
@@ -155,8 +163,6 @@ class BasicMultStepUniVar(UniVariateMultiStep):
         else:
             self.data = data
 
-        self.model_id = ''
-
     def _scaling(self, method: str) -> object:
         '''Scales data accordingly.
             Parameters:
@@ -239,6 +245,12 @@ class BasicMultStepUniVar(UniVariateMultiStep):
         '''
         self.model_id = name
 
+    @property
+    def get_model_id(self) -> str:
+        '''Get model id.
+        '''
+        return self.model_id
+
     @property
     def get_X_input(self) -> array:
         '''Get transformed feature data.
@@ -263,6 +275,12 @@ class BasicMultStepUniVar(UniVariateMultiStep):
         '''
         return self.input_y.shape
 
+    @property
+    def get_optimizer(self) -> str:
+        '''Get model optimizer.
+        '''
+        return self.optimizer
+
     @property
     def get_loss(self) -> str:
         '''Get loss function.
@@ -298,6 +316,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('MLP')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -335,6 +354,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('RNN')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -371,6 +391,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('LSTM')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -410,6 +431,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('CNN')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -446,6 +468,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('GRU')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -479,6 +502,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('BI-RNN')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -512,6 +536,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('BI-LSTM')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -545,6 +570,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('BI-GRU')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -584,6 +610,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('Encoder-Decoder-RNN')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -624,6 +651,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('Encoder-Decoder-LSTM')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -664,6 +692,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('Encoder-Decoder-GRU')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -708,6 +737,7 @@ class BasicMultStepUniVar(UniVariateMultiStep):
                 layer_config (dict): Adjust neurons and acitivation functions.
         '''
         self.set_model_id('Encoder(CNN)-Decoder(GRU)')
+        self.optimizer = optimizer
         self.loss = loss
         self.metrics = metrics
 
@@ -804,10 +834,12 @@ class BasicMultStepUniVar(UniVariateMultiStep):
 
         return pd.DataFrame(y_pred, columns=[f'{self.model_id}'])
 
-    def save_model(self):
+    def save_model(self, absolute_path: str = CURRENT_PATH):
         '''Save the current model to the current directory.
+             Parameters:
+                absolute_path (str): Path to save model to.
         '''
-        self.model.save(os.path.abspath(os.getcwd()))
+        self.model.save(absolute_path)
 
     def load_model(self, location: str):
         '''Load a keras model from the path specified.
